float DigFil(float invar, float initval, bool setic)
/******************************************************************************/
/* Filter Solutions Version 2020                 Nuhertz Technologies, L.L.C. */
/*                                                            www.nuhertz.com */
/*                                                            +1 602-279-2448 */
/* 8th Order High Pass Butterworth                                            */
/* Bilinear Transformation with Prewarping                                    */
/* Sample Frequency = 4.000 KHz                                               */
/* Standard Form                                                              */
/* Arithmetic Precision = 4 Digits                                            */
/*                                                                            */
/* Pass Band Frequency = 186.7 Hz                                             */
/* Pass Band Attenuation = 1 dB                                               */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Input Variable Definitions:                                                */
/* Inputs:                                                                    */
/*   invar    float       The input to the filter                             */
/*   initvar  float       The initial value of the filter                     */
/*   setic    bool        true to initialize the filter to contents of initvar*/
/*                                                                            */
/* Option Selections:                                                         */
/* C++;          Initializable;            Internal States;   Optimized;      */
/*                                                                            */
/* There is no requirement to ever initialize the filter.                     */
/* The default initialization is zero when the filter is first called         */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* This software is automatically generated by Filter Solutions               */
/* no restrictions from Nuhertz Technologies, L.L.C. regarding the use and    */
/* distributions of this software.                                            */
/*                                                                            */
/******************************************************************************/

{
    static float states[8] = {0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    const static float znum[5] = {
        0.4995,
        -3.996,
        13.99,
        -27.97,
        34.97
    };
    const static float zden[8] = {
        0.2495,
        -2.341,
        9.644,
        -22.79,
        33.78,
        -32.19,
        19.26,
        -6.618
    };
    if (setic){
        for (int i=0;i<8;i++) states[i] = 6.799e+04*(invar-initval);
        return initval;
    }
    else{
        float sumden(0.0), sumnum(0.0);
        for (int i=0;i<8;i++){
            sumden += states[i]*zden[i];
            sumnum += states[i]*znum[i<5?i:8-i];
            if (i<7) states[i] = states[i+1];
        }
        states[7] = invar-sumden;
        sumnum += states[7]*znum[0];
        return sumnum;
    }
}
